import { Injectable } from '@angular/core';
import {
  HttpRequest,
  HttpHandler,
  HttpEvent,
  HttpInterceptor
} from '@angular/common/http';
import { Observable } from 'rxjs';
import { AuthService } from '../service/auth.service';
import { environment } from '../../../environments/environment';

@Injectable()
export class AuthInterceptor implements HttpInterceptor {
  constructor(private authenticationService: AuthService) { }

  intercept(request: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
      // add header with basic auth credentials if user is logged in and request is to the api url
      const user = this.authenticationService.user;
      const isLoggedIn = user && user.username && user.password;
      const isAdminUrl = request.url.startsWith(environment.apiUrl);
      if (isLoggedIn && isAdminUrl) {
          request = request.clone({
              setHeaders: {
                  Authorization: this.authenticationService.getUserToken()
              }
          });
      }

      return next.handle(request);
  }
}
